@@ -18,8 +18,8 @@
 #
 # Program: WorkerRsh.pm
 # Author:  Timo Benk <benk@b1-systems.de>
-# Date:    Fri May 24 08:03:19 2013 +0200
-# Ident:   88db47d4612f4742ac757cc09f728ebcaf7f6815
+# Date:    Sat Jun 15 07:47:45 2013 +0200
+# Ident:   c83541ac1d378290dda6cd697ff1308439113a9c
 # Branch:  master
 #
 # Changelog:--reverse --grep '^tags.*relevant':-1:%an : %ai : %s
@@ -31,8 +31,14 @@
 # Timo Benk : 2013-05-21 18:47:43 +0200 : parameter --async added
 # Timo Benk : 2013-05-23 17:26:57 +0200 : comment fixed for delete()
 # Timo Benk : 2013-05-24 08:03:19 +0200 : generic mode added
+# Timo Benk : 2013-06-13 13:59:01 +0200 : process output handling refined
+# Timo Benk : 2013-06-13 20:32:17 +0200 : using __PACKAGE__ is less error-prone
 #
 
+###
+# this worker implements rsh based remote execution
+###
+
 package NRun::Worker::WorkerRsh;
 
 use strict;
@@ -50,7 +56,7 @@ BEGIN {
 
         'MODE' => "rsh",
         'DESC' => "rsh based remote execution",
-        'NAME' => "NRun::Worker::WorkerRsh",
+        'NAME'   => __PACKAGE__,
     } );
 }
 
@@ -75,8 +81,6 @@ sub new {
 # $_cfg - parameter hash where
 # {
 #   'hostname'   - hostname this worker should act on
-#   'dumper'     - dumper object
-#   'logger'     - logger object
 #   'rsh_copy'   - commandline for the copy command (SOURCE, TARGET, HOSTNAME will be replaced)
 #   'rsh_exec'   - commandline for the exec command (COMMAND, ARGUMENTS, HOSTNAME will be replaced)
 #   'rsh_delete' - commandline for the delete command (FILE, HOSTNAME will be replaced)
@@ -111,9 +115,7 @@ sub copy {
     $cmdline =~ s/TARGET/$_target/g;
     $cmdline =~ s/HOSTNAME/$_self->{hostname}/g;
 
-    my ( $out, $ret ) = $_self->do($cmdline);
-
-    return $ret;
+    return $_self->do($cmdline);
 }
 
 ###
@@ -134,9 +136,7 @@ sub execute {
     $cmdline =~ s/ARGUMENTS/$_args/g;
     $cmdline =~ s/HOSTNAME/$_self->{hostname}/g;
 
-    my ( $out, $ret ) = $_self->do($cmdline);
-
-    return $ret;
+    return $_self->do($cmdline);
 }
 
 ###
@@ -154,10 +154,7 @@ sub delete {
     $cmdline =~ s/FILE/$_file/g;
     $cmdline =~ s/HOSTNAME/$_self->{hostname}/g;
 
-    my ( $out, $ret ) = $_self->do($cmdline);
-
-    return $ret;
+    return $_self->do($cmdline);
 }
 
 1;
-
